# Palettepal

Generate color palettes from your terminal.

Install with:

```
pip install palettepal
```

And run from the command line:

```
python -m palettepal
```

Palettepal requires textual and pyperclip.


